## Build Status
Travis CI  | AppVeyor | CircleCI
---------- | -------- | --------
[![linux test status](https://img.shields.io/travis/kshpytsya/tinyshar.svg?label=Linux)](https://travis-ci.org/kshpytsya/tinyshar) | [![windows test status](https://img.shields.io/appveyor/ci/kshpytsya/tinyshar.svg?label=Windows&logo=appveyor)](https://ci.appveyor.com/project/kshpytsya/tinyshar) | [![macOS test status](https://img.shields.io/circleci/project/github/kshpytsya/tinyshar.svg?label=macOS)](https://circleci.com/gh/kshpytsya/tinyshar)

# tinyshar
simple Python library and utility for creation of shell archives

Documentation is available [here](https://tinyshar-docs.surge.sh) -- work in progress.
